This is an automated email from the ASF dual-hosted git repository.

lidavidm pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/arrow-adbc.git


The following commit(s) were added to refs/heads/main by this push:
     new d9439e2e chore(go): bump to 1.19 minimum (#1053)
d9439e2e is described below

commit d9439e2e9a4b4f05824a4bd304d2eba0a735ce8a
Author: David Li <[email protected]>
AuthorDate: Tue Sep 12 08:06:35 2023 -0400

    chore(go): bump to 1.19 minimum (#1053)
    
    Fixes #1052.
    
    Co-authored-by: Sutou Kouhei <[email protected]>
---
 .github/workflows/integration.yml             |  4 ++--
 .github/workflows/native-unix.yml             | 14 +++++++-------
 .github/workflows/native-windows.yml          |  6 +++---
 .github/workflows/packaging.yml               |  4 ++--
 ci/conda/meta.yaml                            |  2 +-
 ci/conda_env_cpp.txt                          |  3 +--
 ci/docker/python-wheel-manylinux.dockerfile   |  4 ++--
 ci/linux-packages/apt/ubuntu-jammy/Dockerfile |  6 +++++-
 ci/linux-packages/debian/control              |  2 +-
 ci/linux-packages/debian/rules                | 24 +++++++++++++-----------
 dev/release/verify-release-candidate.ps1      |  9 ++++++---
 dev/release/verify-release-candidate.sh       |  2 +-
 r/adbcflightsql/tools/download-go.R           |  2 +-
 r/adbcsnowflake/tools/download-go.R           |  2 +-
 14 files changed, 46 insertions(+), 38 deletions(-)

diff --git a/.github/workflows/integration.yml 
b/.github/workflows/integration.yml
index c8cf5cdd..f9fef8b2 100644
--- a/.github/workflows/integration.yml
+++ b/.github/workflows/integration.yml
@@ -130,7 +130,7 @@ jobs:
             --file ci/conda_env_python.txt
       - uses: actions/setup-go@v3
         with:
-          go-version: 1.18.10
+          go-version: 1.19.13
           check-latest: true
           cache: true
           cache-dependency-path: go/adbc/go.sum
@@ -293,7 +293,7 @@ jobs:
             --file ci/conda_env_python.txt
       - uses: actions/setup-go@v3
         with:
-          go-version: 1.18.10
+          go-version: 1.19.13
           check-latest: true
           cache: true
           cache-dependency-path: go/adbc/go.sum
diff --git a/.github/workflows/native-unix.yml 
b/.github/workflows/native-unix.yml
index e3a1bac3..a88eb9c5 100644
--- a/.github/workflows/native-unix.yml
+++ b/.github/workflows/native-unix.yml
@@ -98,7 +98,7 @@ jobs:
             --file ci/conda_env_cpp.txt
       - uses: actions/setup-go@v3
         with:
-          go-version: 1.18.10
+          go-version: 1.19.13
           check-latest: true
           cache: true
           cache-dependency-path: go/adbc/go.sum
@@ -112,14 +112,14 @@ jobs:
           export ADBC_BUILD_TESTS=OFF
           export ADBC_USE_ASAN=OFF
           export ADBC_USE_UBSAN=OFF
-          export PATH=$RUNNER_TOOL_CACHE/go/1.18.10/x64/bin:$PATH
+          export PATH=$RUNNER_TOOL_CACHE/go/1.19.13/x64/bin:$PATH
           ./ci/scripts/cpp_build.sh "$(pwd)" "$(pwd)/build" "$HOME/local"
       - name: Go Build
         shell: bash -l {0}
         env:
           CGO_ENABLED: "1"
         run: |
-          export PATH=$RUNNER_TOOL_CACHE/go/1.18.10/x64/bin:$PATH
+          export PATH=$RUNNER_TOOL_CACHE/go/1.19.13/x64/bin:$PATH
           ./ci/scripts/go_build.sh "$(pwd)" "$(pwd)/build" "$HOME/local"
 
       - uses: actions/upload-artifact@v3
@@ -361,7 +361,7 @@ jobs:
             --file ci/conda_env_cpp.txt
       - uses: actions/setup-go@v3
         with:
-          go-version: 1.18.10
+          go-version: 1.19.13
           check-latest: true
           cache: true
           cache-dependency-path: go/adbc/go.sum
@@ -378,7 +378,7 @@ jobs:
       - name: Go Build
         shell: bash -l {0}
         run: |
-          export PATH=$RUNNER_TOOL_CACHE/go/1.18.10/x64/bin:$PATH
+          export PATH=$RUNNER_TOOL_CACHE/go/1.19.13/x64/bin:$PATH
           ./ci/scripts/go_build.sh "$(pwd)" "$(pwd)/build" "$HOME/local"
       - name: Run Staticcheck
         if: ${{ !contains('macos-latest', matrix.os) }}
@@ -392,7 +392,7 @@ jobs:
         env:
           SNOWFLAKE_URI: ${{ secrets.SNOWFLAKE_URI }}
         run: |
-          export PATH=$RUNNER_TOOL_CACHE/go/1.18.10/x64/bin:$PATH
+          export PATH=$RUNNER_TOOL_CACHE/go/1.19.13/x64/bin:$PATH
           ./ci/scripts/go_test.sh "$(pwd)" "$(pwd)/build" "$HOME/local"
 
   # ------------------------------------------------------------
@@ -441,7 +441,7 @@ jobs:
             --file ci/conda_env_python.txt
       - uses: actions/setup-go@v3
         with:
-          go-version: 1.18.10
+          go-version: 1.19.13
           check-latest: true
           cache: true
           cache-dependency-path: go/adbc/go.sum
diff --git a/.github/workflows/native-windows.yml 
b/.github/workflows/native-windows.yml
index a6851374..5545a7f4 100644
--- a/.github/workflows/native-windows.yml
+++ b/.github/workflows/native-windows.yml
@@ -223,7 +223,7 @@ jobs:
             --file ci/conda_env_cpp.txt
       - uses: actions/setup-go@v3
         with:
-          go-version: 1.18.10
+          go-version: 1.19.13
           check-latest: true
           cache: true
           cache-dependency-path: go/adbc/go.sum
@@ -238,7 +238,7 @@ jobs:
         env:
           CGO_ENABLED: "1"
         run: |
-          $env:PATH="$($env:RUNNER_TOOL_CACHE)\go\1.18.10\x64\bin;" + $env:PATH
+          $env:PATH="$($env:RUNNER_TOOL_CACHE)\go\1.19.13\x64\bin;" + $env:PATH
           .\ci\scripts\go_build.ps1 $pwd $pwd\build
       # TODO(apache/arrow#358): enable these tests on Windows
       # - name: Go Test
@@ -246,7 +246,7 @@ jobs:
       #   env:
       #     CGO_ENABLED: "1"
       #   run: |
-      #     $env:PATH="$($env:RUNNER_TOOL_CACHE)\go\1.18.10\x64\bin;" + 
$env:PATH
+      #     $env:PATH="$($env:RUNNER_TOOL_CACHE)\go\1.19.13\x64\bin;" + 
$env:PATH
       #     .\ci\scripts\go_test.ps1 $pwd $pwd\build
 
   # ------------------------------------------------------------
diff --git a/.github/workflows/packaging.yml b/.github/workflows/packaging.yml
index 3c0b8762..7d4534df 100644
--- a/.github/workflows/packaging.yml
+++ b/.github/workflows/packaging.yml
@@ -607,7 +607,7 @@ jobs:
 
       - uses: actions/setup-go@v3
         with:
-          go-version: 1.18.10
+          go-version: 1.19.13
           check-latest: true
           cache: true
           cache-dependency-path: adbc/go/adbc/go.sum
@@ -729,7 +729,7 @@ jobs:
 
       - uses: actions/setup-go@v3
         with:
-          go-version: 1.18.10
+          go-version: 1.19.13
           check-latest: true
           cache: true
           cache-dependency-path: adbc/go/adbc/go.sum
diff --git a/ci/conda/meta.yaml b/ci/conda/meta.yaml
index 66d66cbf..9704c18f 100644
--- a/ci/conda/meta.yaml
+++ b/ci/conda/meta.yaml
@@ -63,7 +63,7 @@ outputs:
         - {{ compiler('cxx') }}
         - _go_select *=cgo
         - cmake
-        - go-cgo >=1.18
+        - go-cgo >=1.19
         - ninja
         - pkg-config
     test:
diff --git a/ci/conda_env_cpp.txt b/ci/conda_env_cpp.txt
index 2587a3ce..61010a33 100644
--- a/ci/conda_env_cpp.txt
+++ b/ci/conda_env_cpp.txt
@@ -19,7 +19,6 @@ cmake
 compilers
 gtest>=1.10.0
 libpq
-ninja
-pkg-config
 libsqlite
+ninja
 pkg-config
diff --git a/ci/docker/python-wheel-manylinux.dockerfile 
b/ci/docker/python-wheel-manylinux.dockerfile
index aeac91e0..38d3b27b 100644
--- a/ci/docker/python-wheel-manylinux.dockerfile
+++ b/ci/docker/python-wheel-manylinux.dockerfile
@@ -27,6 +27,6 @@ ARG ARCH
 
 RUN yum install -y docker
 # arm64v8 -> arm64
-RUN wget --no-verbose https://go.dev/dl/go1.18.10.linux-${ARCH/v8/}.tar.gz
-RUN tar -C /usr/local -xzf go1.18.10.linux-${ARCH/v8/}.tar.gz
+RUN wget --no-verbose https://go.dev/dl/go1.19.13.linux-${ARCH/v8/}.tar.gz
+RUN tar -C /usr/local -xzf go1.19.13.linux-${ARCH/v8/}.tar.gz
 ENV PATH="${PATH}:/usr/local/go/bin"
diff --git a/ci/linux-packages/apt/ubuntu-jammy/Dockerfile 
b/ci/linux-packages/apt/ubuntu-jammy/Dockerfile
index 0c08f55a..bc5708e3 100644
--- a/ci/linux-packages/apt/ubuntu-jammy/Dockerfile
+++ b/ci/linux-packages/apt/ubuntu-jammy/Dockerfile
@@ -38,6 +38,9 @@ RUN \
   apt install -y -V ${quiet} \
     ./apache-arrow-apt-source-latest-$(lsb_release --codename --short).deb && \
   rm apache-arrow-apt-source-latest-$(lsb_release --codename --short).deb && \
+  grep " $(lsb_release --codename --short) " /etc/apt/sources.list | \
+    sed -e "s/$(lsb_release --codename --short)/$(lsb_release --codename 
--short)-backports/g" > \
+    /etc/apt/sources.list.d/backports.list && \
   apt update && \
   apt install -y -V ${quiet} \
     build-essential \
@@ -46,7 +49,6 @@ RUN \
     debhelper \
     devscripts \
     gobject-introspection \
-    golang \
     libarrow-glib-dev \
     libgirepository1.0-dev \
     libpq-dev \
@@ -56,4 +58,6 @@ RUN \
     pkg-config \
     tzdata \
     valac && \
+  apt install -y -V -t $(lsb_release --codename --short)-backports ${quiet} \
+    golang-1.20 && \
   apt clean
diff --git a/ci/linux-packages/debian/control b/ci/linux-packages/debian/control
index 2b4a06a5..312831f9 100644
--- a/ci/linux-packages/debian/control
+++ b/ci/linux-packages/debian/control
@@ -23,7 +23,7 @@ Build-Depends:
   cmake,
   debhelper-compat (= 12),
   gobject-introspection,
-  golang,
+  golang | golang-1.20,
   libgirepository1.0-dev,
   libpq-dev,
   libsqlite3-dev,
diff --git a/ci/linux-packages/debian/rules b/ci/linux-packages/debian/rules
index 6f92b62b..b56d1a8a 100755
--- a/ci/linux-packages/debian/rules
+++ b/ci/linux-packages/debian/rules
@@ -31,17 +31,19 @@ export DEB_BUILD_MAINT_OPTIONS=reproducible=-timeless
 CMAKE_BUILD_TYPE = RelWithDebInfo
 
 override_dh_auto_configure:
-       dh_auto_configure                               \
-         --sourcedirectory=c/                          \
-         --builddirectory=c.build                      \
-         --buildsystem=cmake+ninja                     \
-         --                                            \
-         -DCMAKE_BUILD_TYPE=$(CMAKE_BUILD_TYPE)        \
-          -DADBC_DRIVER_MANAGER=ON                      \
-          -DADBC_DRIVER_POSTGRESQL=ON                   \
-          -DADBC_DRIVER_SQLITE=ON                       \
-          -DADBC_DRIVER_FLIGHTSQL=ON                    \
-          -DADBC_DRIVER_SNOWFLAKE=ON
+       env \
+         PATH=/usr/lib/go-1.20/bin:$${PATH}            \
+         dh_auto_configure                             \
+           --sourcedirectory=c/                        \
+           --builddirectory=c.build                    \
+           --buildsystem=cmake+ninja                   \
+           --                                          \
+           -DCMAKE_BUILD_TYPE=$(CMAKE_BUILD_TYPE)      \
+            -DADBC_DRIVER_MANAGER=ON                    \
+            -DADBC_DRIVER_POSTGRESQL=ON                 \
+            -DADBC_DRIVER_SQLITE=ON                     \
+            -DADBC_DRIVER_FLIGHTSQL=ON                  \
+            -DADBC_DRIVER_SNOWFLAKE=ON
 
 override_dh_auto_build:
        dh_auto_build                                   \
diff --git a/dev/release/verify-release-candidate.sh 
b/dev/release/verify-release-candidate.sh
index 9e12e542..fcf9a33b 100755
--- a/dev/release/verify-release-candidate.sh
+++ b/dev/release/verify-release-candidate.sh
@@ -254,7 +254,7 @@ install_go() {
     return 0
   fi
 
-  local version=1.18.10
+  local version=1.19.13
   show_info "Installing go version ${version}..."
 
   local arch="$(uname -m)"
diff --git a/r/adbcflightsql/tools/download-go.R 
b/r/adbcflightsql/tools/download-go.R
index 262d153a..4b490973 100644
--- a/r/adbcflightsql/tools/download-go.R
+++ b/r/adbcflightsql/tools/download-go.R
@@ -17,7 +17,7 @@
 
 tmp_dir <- "src/go/tmp"
 
-go_version <- Sys.getenv("R_ADBC_GO_VERSION_DOWNLOAD", "1.18.10")
+go_version <- Sys.getenv("R_ADBC_GO_VERSION_DOWNLOAD", "1.19.13")
 
 go_platform <- tolower(Sys.info()[["sysname"]])
 if (!(go_platform %in% c("darwin", "linux", "windows"))) {
diff --git a/r/adbcsnowflake/tools/download-go.R 
b/r/adbcsnowflake/tools/download-go.R
index 262d153a..4b490973 100644
--- a/r/adbcsnowflake/tools/download-go.R
+++ b/r/adbcsnowflake/tools/download-go.R
@@ -17,7 +17,7 @@
 
 tmp_dir <- "src/go/tmp"
 
-go_version <- Sys.getenv("R_ADBC_GO_VERSION_DOWNLOAD", "1.18.10")
+go_version <- Sys.getenv("R_ADBC_GO_VERSION_DOWNLOAD", "1.19.13")
 
 go_platform <- tolower(Sys.info()[["sysname"]])
 if (!(go_platform %in% c("darwin", "linux", "windows"))) {

Reply via email to
diff --git a/dev/release/verify-release-candidate.ps1 
b/dev/release/verify-release-candidate.ps1
index fcf4cc41..dd51b56d 100755
--- a/dev/release/verify-release-candidate.ps1
+++ b/dev/release/verify-release-candidate.ps1
@@ -119,9 +119,12 @@ mamba create -c conda-forge -f -y -p $(Join-Path 
$ArrowTempDir conda-env) `
 
 Invoke-Expression $(conda shell.powershell hook | Out-String)
 conda activate $(Join-Path $ArrowTempDir conda-env)
-# XXX: force bundled gtest as the conda-forge version appears to
-# require you to exactly match the MSVC version it was compiled with
-mamba uninstall gtest
+# XXX: force bundled gtest as the conda-forge version appears to require you
+# to exactly match the MSVC version it was compiled with.  Uninstalling also
+# removes a bunch of other things, so force-remove instead
+# (https://github.com/conda-forge/libprotobuf-feedstock/issues/186)
+# Use conda, mamba appears to ignore --force
+conda remove --force gtest
 
 # Activating doesn't appear to set GOROOT
 $env:GOROOT = $(Join-Path $ArrowTempDir conda-env go)